@@ -9,25 +9,34 @@ import json
 import os
 from io import StringIO
 
-from pylint import checkers
+import pytest
 from pylint.lint import PyLinter
 
-from pylint_gitlab.reporter import GitlabCodeClimateReporter, GitlabPagesHtmlReporter
 
-
-def test_gitlab_pages_html_reporter():
+@pytest.mark.parametrize("use_load_plugins", [False, True])
+def test_gitlab_pages_html_reporter(use_load_plugins):
     """Tests for ``pylint_gitlab.reporter.GitlabPagesHtmlReporter()``."""
 
-    output = StringIO()
+    if use_load_plugins:
+        plugins = ["pylint_gitlab"]
+        reporter = "gitlab-pages-html"
+    else:
+        plugins = []
+        reporter = "pylint_gitlab.GitlabPagesHtmlReporter"
 
-    reporter = GitlabPagesHtmlReporter()
+    output = StringIO()
+    linter = PyLinter()
+
+    linter.load_plugin_modules(plugins)
+    linter.set_option("output-format", reporter)
+    linter.set_option("persistent", False)
+    linter.load_default_plugins()
+
+    reporter = linter.reporter
+    reporter.set_output(output)
     reporter.CI_PROJECT_URL = "https://example.org"
     reporter.CI_COMMIT_REF_NAME = "branch"
-    linter = PyLinter(reporter=reporter)
-    checkers.initialize(linter)
 
-    linter.config.persistent = 0
-    linter.reporter.set_output(output)
     linter.open()
 
     linter.set_current_module("b")
@@ -45,18 +54,30 @@ def test_gitlab_pages_html_reporter():
     assert output.getvalue() == expected_result
 
 
-def test_gitlab_code_climate_reporter():
+@pytest.mark.parametrize("use_load_plugins", [False, True])
+def test_gitlab_code_climate_reporter(use_load_plugins):
     """Tests for ``pylint_gitlab.reporter.GitlabCodeClimateReporter()``."""
 
+    if use_load_plugins:
+        plugins = ["pylint_gitlab"]
+        reporter = "gitlab-codeclimate"
+    else:
+        plugins = []
+        reporter = "pylint_gitlab.GitlabCodeClimateReporter"
+
     output = StringIO()
+    linter = PyLinter()
 
-    reporter = GitlabCodeClimateReporter()
-    linter = PyLinter(reporter=reporter)
-    checkers.initialize(linter)
+    linter.load_plugin_modules(plugins)
+    linter.set_option("output-format", reporter)
+    linter.set_option("persistent", False)
+    linter.load_default_plugins()
+
+    reporter = linter.reporter
+    reporter.set_output(output)
 
-    linter.config.persistent = 0
-    linter.reporter.set_output(output)
     linter.open()
+
     linter.set_current_module("0123")
     linter.add_message("line-too-long", line=1, args=(1, 2))
 
